@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2007 Shintaro Matsuoka <shin@shoegazed.org>
-  Copyright (C) 2009 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2007 Shintaro Matsuoka <shin@shoegazed.org>
+    SPDX-FileCopyrightText: 2009 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #ifndef DCCCOMMON_H
@@ -34,15 +29,12 @@ namespace Konversation
                 static QString numericalIpToTextIp( const QString& numericalIp );
 
                 // returns the self IP following the setting.
-                static QString getOwnIp( Server* server = 0 );
+                static QString getOwnIp( Server* server = nullptr );
 
                 static QString ipv6FallbackAddress(const QString& address);
 
                 // creates an instance of QTcpServer following the DCC settings
-                static QTcpServer* createServerSocketAndListen( QObject* parent = 0, QString* failedReason = 0, int minPort = 0, int maxPort = 0 );
-
-                // returns a updateinterval according to KGlobalSettings::graphicEffectsLevel()
-                static int graphicEffectLevelToUpdateInterval(int value);
+                static QTcpServer* createServerSocketAndListen( QObject* parent = nullptr, QString* failedReason = nullptr, int minPort = 0, int maxPort = 0 );
 
             private:
                 DccCommon();
